@@ -39,17 +39,73 @@ var Analyzers = []*analysis.Analyzer{
 	SSRFAnalyzer,
 }
 
+func FilterResults(unfilteredResults []util.Finding, parent_dir string) ([]util.Finding, error) {
+	filteredResults := []util.Finding{}
+
+	for _, finding := range unfilteredResults {
+		finding.Vulnerable_Function.SourceFilename = strings.TrimPrefix(finding.Vulnerable_Function.SourceFilename, parent_dir)
+		if finding.Untrusted_Source != nil {
+			for i, source := range finding.Untrusted_Source {
+				finding.Untrusted_Source[i].SourceFilename = strings.TrimPrefix(source.SourceFilename, parent_dir)
+			}
+		}
+		if util.IsValidFinding(finding) {
+			filteredResults = append(filteredResults, finding)
+		}
+	}
+
+	return filteredResults, nil
+}
+
+func OutputResults(results []util.Finding, success bool) error {
+	var stdOutPipe, outputFile *os.File
+
+	if util.Config.OutputPath != "" {
+		stdOutPipe = os.Stdout // keep backup of the real stdout
+		// open file read/write | create if not exist | clear file at open if exists
+		outputFile, err := os.OpenFile(util.Config.OutputPath, os.O_RDWR|os.O_CREATE|os.O_TRUNC, 0666)
+		if err != nil {
+			return err
+		}
+		os.Stdout = outputFile
+	}
+
+	for _, finding := range results {
+		util.OutputFinding(finding)
+	}
+
+	// if packages were able to be scanned, print the correct output message
+	if util.Config.OutputSarif && success {
+		util.SarifPrintReport()
+		fmt.Println()
+	}
+
+	// if output was redirected for findings, change it back to the original stdout
+	if util.Config.OutputPath != "" {
+		outputFile.Close()
+		os.Stdout = stdOutPipe // restoring the real stdout
+	}
+
+	return nil
+}
+
 func Scan(args []string) {
+	//Get the current dir so we can reset it later.
+	current_dir, err := os.Getwd()
+	if err != nil {
+		fmt.Printf("Unable to get current dir.\n")
+	}
+
 	if util.Config.OutputSarif {
 		util.InitSarifReporting()
 	} else {
 		fmt.Printf("\nRevving engines VRMMM VRMMM\n3...2...1...Go!\n")
 	}
-
 	// If we're given a target path, we do some slight changes to make sure that
 	// gokart will behave as expected. Specifically we turn the path into an absolute
 	// path, and then we append /... to the end to make sure the package loading is recursive.
 	// Finally we update the current working directory to the target
+	// In order to not cause issues we set the working directory back after we are done scanning.
 	if len(args) > 0 {
 		target_path := args[0]
 		if !filepath.IsAbs(target_path) {
@@ -94,7 +150,7 @@ func Scan(args []string) {
 	// Run analyzers
 	results, success, err := run.Run(Analyzers, args...)
 	if err != nil {
-		panic(err)
+		log.Fatal(err)
 	}
 	// Calculate time taken
 	scan_time := time.Since(run_begin_time)
@@ -117,24 +173,21 @@ func Scan(args []string) {
 		parent_dir += "/"
 	}
 
-	count := 0
-	for _, finding := range results {
-		finding.Vulnerable_Function.SourceFilename = strings.TrimPrefix(finding.Vulnerable_Function.SourceFilename, parent_dir)
-		if finding.Untrusted_Source != nil {
-			for i, source := range finding.Untrusted_Source {
-				finding.Untrusted_Source[i].SourceFilename = strings.TrimPrefix(source.SourceFilename, parent_dir)
-			}
-		}
-		if util.OutputFinding(finding) {
-			count++
-		}
+	// fix-up our results to exclude invalid results + shorten long directory names
+	filteredResults, err := FilterResults(results, parent_dir)
+	if err != nil {
+		log.Fatal(err)
 	}
-	// if packages were able to be scanned, print the correct output message
-	if util.Config.OutputSarif && success {
-		util.SarifPrintReport()
-		fmt.Println()
-	} else if success {
+
+	// output findings to stdout or specified output file
+	err = OutputResults(filteredResults, success)
+	if err != nil {
+		log.Fatalf("Error opening output file: %v", err)
+	}
+
+	if !util.Config.OutputSarif && success {
 		fmt.Println("\nRace Complete! Analysis took", scan_time, "and", util.FilesFound, "Go files were scanned (including imported packages)")
-		fmt.Printf("GoKart found %d potentially vulnerable functions\n", count)
+		fmt.Printf("GoKart found %d potentially vulnerable functions\n", len(filteredResults))
 	}
+	os.Chdir(current_dir)
 }
